@@ -197,13 +197,15 @@ class ModelInstance:
         # get chat history interactions with pagination
         url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/chat_history'
         response = _format_http_response(requests.get(url, headers=HEADERS))
-        print('get_chat_history debugging')
+        print('START CHAT HISTORY DEBUGGING')
         print(url)
         print(response)
         self.chat_history.extend(response['body']['interactions'])
         while 'next_page_token' in response:
             response = _format_http_response(requests.get(url, headers=HEADERS, params={'next_page_token': response['next_page_token']}))
             self.chat_history.extend(response['body']['interactions'])
+        print(self.chat_history)
+        print('END CHAT HISTORY DEBUGGING')
 
     def create(self):
         if self.is_deployed:
